/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

.site {
  -moz-binding: url("chrome://browser/content/permissions/aboutPermissions.xml#site");
}

.pluginPermission {
  -moz-binding: url("chrome://browser/content/permissions/aboutPermissions.xml#pluginPermission");
}
