/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

%include ../../shared/statusbar/overlay.css

/*
 * General
 */

#status4evar-status-text,
#status4evar-progress-bar
{
	margin: 0px 3px;
}

/*
 * Download status
 */

#status4evar-download-progress-bar
{
	height: 4px;
}

#status4evar-download-button #status4evar-download-icon
{
	min-width: 18px;
	min-height: 18px;
}

#status4evar-download-button #status4evar-download-icon
{
	background: -moz-image-rect(var(--toolbarbutton-image), 0, 108, 18, 90) center no-repeat;
}

toolbar[brighttext] #status4evar-download-button #status4evar-download-icon
{
	background: -moz-image-rect(var(--toolbarbutton-inverted-image), 0, 108, 18, 90) center no-repeat;
}

@media (-moz-windows-compositor)
{
  :-moz-any(#toolbar-menubar, #nav-bar[tabsontop=false]) #status4evar-download-button #status4evar-download-icon:not(:-moz-lwtheme),
  #TabsToolbar[tabsontop=true] #status4evar-download-button #status4evar-download-icon:not(:-moz-lwtheme),
  #nav-bar + #customToolbars + #PersonalToolbar[collapsed=true] + #TabsToolbar[tabsontop=false]:last-child #status4evar-download-button #status4evar-download-icon:not(:-moz-lwtheme)
  {
    background: -moz-image-rect(var(--toolbarbutton-glass-image), 0, 108, 18, 90) center no-repeat;
  }
}

#status4evar-download-button[attention] #status4evar-download-icon
{
	background: -moz-image-rect(var(--toolbarbutton-glass-image), 19, 108, 36, 90) center no-repeat;
}

toolbar[mode="icons"] #status4evar-download-button[forcelabel="true"] > label
{
	margin-inline-start: 5px !important;
}

/*
 * Splitter
 */

splitter.status4evar-status-splitter
{
	width: 6px;
	margin: 0px -3px;
}

/*
 * Location bar
 */

#urlbar-progress-alt
{
	margin-inline-end: -2px;
}

/*
 * Status bar
 */

#browser-bottombox[s4eboarder="true"] :-moz-any(#status4evar-status-bar, #addon-bar)
{
	appearance: none;
}

#browser-bottombox[s4eboarder="true"] > *:not([hidden="true"]):not([collapsed="true"])
{
	box-shadow: none !important;
	border: none !important;
	border-top: 2px solid !important;
	-moz-border-top-colors: ThreeDShadow ThreeDHighlight !important;
}

#browser-bottombox[s4eboarder="true"] > *:not([hidden="true"]):not([collapsed="true"]) ~ *
{
	border: none !important;
}

