/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

%include ../../shared/newtab/newTab.css.inc

.newtab-undo-button {
  appearance: none;
  color: -moz-nativehyperlinktext;
  color: rgb(78,114,204);
  cursor: pointer;
  padding: 0;
  margin: 0 4px;
  border: 0;
  background: transparent;
  text-decoration: none;
  min-width: 0;
}

.newtab-undo-button > .button-box {
  padding: 0;
}

#newtab-undo-close-button {
  background-image: -moz-image-rect(url("chrome://global/skin/icons/close.svg"), 0, 16, 16, 0);
  background-position: center center;
  background-repeat: no-repeat;
}

#newtab-undo-close-button:hover {
  background-image: -moz-image-rect(url("chrome://global/skin/icons/close.svg"), 0, 32, 16, 16);
}

#newtab-undo-close-button:hover:active {
  background-image: -moz-image-rect(url("chrome://global/skin/icons/close.svg"), 0, 48, 16, 32);
}
