/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMWindow;

[scriptable, uuid(33d0433d-07be-4dc4-87fd-954057310efd)]
interface nsIStatus4Evar : nsISupports
{
  readonly attribute boolean   addonbarBorderStyle;
  readonly attribute boolean   addonbarCloseButton;
  readonly attribute boolean   addonbarLegacyShim;
  readonly attribute boolean   addonbarWindowGripper;

  readonly attribute boolean   advancedStatusDetectFullScreen;
  readonly attribute boolean   advancedStatusDetectVideo;

  readonly attribute long      downloadButtonAction;
  readonly attribute ACString  downloadButtonActionCommand;
  readonly attribute ACString  downloadColorActive;
  readonly attribute ACString  downloadColorPaused;
  readonly attribute boolean   downloadForce;
  readonly attribute long      downloadLabel;
  readonly attribute boolean   downloadLabelForce;
  readonly attribute boolean   downloadNotifyAnimate;
  readonly attribute long      downloadNotifyTimeout;
  readonly attribute long      downloadProgress;
  readonly attribute long      downloadTooltip;

  readonly attribute boolean   firstRun;
  readonly attribute boolean   firstRunAustralis;

  readonly attribute ACString  progressToolbarCSS;
  readonly attribute boolean   progressToolbarForce;
  readonly attribute boolean   progressToolbarStyle;
  readonly attribute boolean   progressToolbarStyleAdvanced;

  readonly attribute long      status;
  readonly attribute boolean   statusDefault;
  readonly attribute boolean   statusNetwork;
  readonly attribute boolean   statusNetworkXHR;
  readonly attribute long      statusTimeout;
  readonly attribute long      statusLinkOver;
  readonly attribute long      statusLinkOverDelayShow;
  readonly attribute long      statusLinkOverDelayHide;

  readonly attribute long      statusToolbarMaxLength;

  readonly attribute boolean   statusToolbarInvertMirror;
  readonly attribute boolean   statusToolbarMouseMirror;

  void resetPrefs();
  void updateWindow(in nsIDOMWindow win);
};

