/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

:root {
  --toolbar-custom-color: hsl(210,75%,92%);
  --toolbar-highlight-top: rgba(255,255,255,.5);
  --toolbarbutton-image: url("chrome://browser/skin/Toolbar.png");
  --library-toolbar-image: url("chrome://browser/skin/places/libraryToolbar.png");
}

/* Use SVG for HiDPI 133%+ */
@media (min-resolution: 1.33dppx) {
  :root {
    --toolbarbutton-image: url("chrome://browser/skin/Toolbar.svg");
    --library-toolbar-image: url("chrome://browser/skin/places/libraryToolbar.svg");
  }
}

/* Toolbar */
#placesToolbar {
  padding: 3px;
  padding-inline-end: 6px;
}

#placesToolbar > toolbarbutton[disabled] > .toolbarbutton-icon {
  opacity: .4;
}

#back-button,
#forward-button {
  list-style-image: var(--toolbarbutton-image);
}

#back-button {
  -moz-image-region: rect(0, 18px, 18px, 0);
}

#forward-button {
  -moz-image-region: rect(0, 36px, 18px, 18px);
}

#back-button:-moz-locale-dir(rtl) > .toolbarbutton-icon,
#forward-button:-moz-locale-dir(rtl) > .toolbarbutton-icon {
  transform: scaleX(-1);
}

/* Menu */
#placesMenu {
  margin-inline-start: 6px;
  appearance: none;
  border: none;
}

#placesMenu > menu {
  padding-inline-start: 4px;
  padding-inline-end: 1px;
  padding-top: 2px;
  padding-bottom: 2px;
  appearance: toolbarbutton;
%ifdef XP_WIN
% use standard menu colors on OS/2
  color: -moz-DialogText;
%endif
  border: 1px solid transparent;
}

#placesMenu > menu[_moz-menuactive="true"] {
  background-color: transparent;
}

#placesMenu > menu:hover {
  border-color: ThreeDHighlight ThreeDShadow ThreeDShadow ThreeDHighlight;
}

#placesMenu > menu[open="true"] {
  border-color: ThreeDShadow ThreeDHighlight ThreeDHighlight ThreeDShadow;
  padding-inline-start: 5px;
  padding-inline-end: 0px;
  padding-top: 3px;
  padding-bottom: 1px;
}

#placesMenu > menu > .menubar-text {
  padding-inline-end: 8px;
  background: url(chrome://global/skin/arrow/arrow-dn.gif) right center no-repeat;
}

#placesMenu > menu > .menubar-text:-moz-locale-dir(rtl) {
  background-position: left center;
}

/* organize, view and maintenance buttons icons */
#organizeButton, 
#viewMenu, 
#maintenanceButton {
  list-style-image: var(--library-toolbar-image);
}

/* organize button */
#organizeButton {
  -moz-image-region: rect(0px, 16px, 16px, 0px);
}

/* view button */
#viewMenu {
  -moz-image-region: rect(0px, 32px, 16px, 16px);
}

/* maintenance button */
#maintenanceButton {
  -moz-image-region: rect(0px, 48px, 16px, 32px);
}

/* Root View */
#placesView {
  border-top: 1px solid ThreeDDarkShadow;
}

/* Info box */
#detailsDeck {
  border-top: 1px solid ThreeDShadow;
  padding: 5px;
}

#infoBoxExpanderLabel {
  padding-inline-start: 2px;
}

#organizerScopeBar {
  padding: 2px 0;
  padding-inline-end: 3px;
}

#organizerScopeBar > toolbarbutton {
  appearance: none;
  border: 1px solid transparent;
  border-radius: 2px;
  padding: 0 !important;
  margin: 0 1px;
}

#organizerScopeBar > toolbarbutton > .toolbarbutton-icon {
  padding: 0;
  margin: 0;
}

#organizerScopeBar > toolbarbutton > .toolbarbutton-text {
   margin: 0;
   padding: 2px 5px;
}

#organizerScopeBar > toolbarbutton:not([disabled="true"]):not([checked="true"]):hover {
  border-color: ThreeDShadow;
}

#organizerScopeBar > toolbarbutton[checked="true"] {
  border-color: ThreeDDarkShadow !important;
}

#searchFilter {
  margin: 0;
}

/**
 * Downloads pane
 */

#clearDownloadsButton > .toolbarbutton-icon {
  display: none;
}

#clearDownloadsButton {
  padding-inline-start: 9px;
  padding-inline-end: 9px;
}

#placesView {
  border-top: none;
}

@media not all and (-moz-windows-classic) {
  #placesToolbox {
    appearance: none;
    background-color: transparent;
  }

  #placesToolbar {
    appearance: none;
    background-color: -moz-Dialog;
    color: -moz-dialogText;
  }
}

@media (-moz-windows-default-theme) {
  #placesView > splitter {
    border: 0;
    border-inline-end: 1px solid #A9B7C9;
    min-width: 0;
    width: 3px;
    background-color: transparent;
    margin-inline-start: -3px;
    position: relative;
  }
}

@media (-moz-windows-glass) {
  #placesToolbox {
    border-top: none;
  }

  #placesToolbar {
    background-image: linear-gradient(var(--toolbar-highlight-top), transparent);
  }
}

@media (-moz-os-version: windows-win10) and (-moz-windows-theme: aero) {
  #placesToolbox {
    /* Override the global style for Windows 10 that adds a bottom border */
    border-bottom: none;
  }
}

@media (-moz-windows-default-theme) and (-moz-os-version: windows-win7) {
  #placesView,
  #infoPane,
  #placesList,
  #placeContent {
    background-color: #EEF3FA;
  }

  #placesToolbar {
    background-color: var(--toolbar-custom-color);
    color: black;
  }

  #detailsDeck {
    border-top-color: #A9B7C9;
  }

  #searchFilter {
    appearance: none;
    padding: 2px;
    padding-inline-start: 4px;
    background-clip: padding-box;
    border: 1px solid rgba(0,0,0,.32);
    border-radius: 2px;
  }
}
