/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#aboutPMDialogContainer {
  background-image: url("chrome://branding/content/about-background.png");
  background-repeat: no-repeat;
  background-color: #000;
  color: #fff;
}

#aboutVersionBox {
  /* No wordmark: leave empty space */
  margin-top: 20px;
}

#aboutLinkBox {
  padding: 15px 10px 20px;
}
