#padlock-ib {
  appearance: none;
  min-width: 0px;
  margin-right: 1px !important;
  background-repeat: no-repeat;
  background-position: center;
  z-index: 1000 !important;
  padding: 0px;
  margin: 0px;
  border: 0px; 
}

#padlock-ib[padshow="ib-trans-bg"][level="ev"] {
  list-style-image: url("chrome://browser/content/padlock_mod_ev.png");
  background-color: transparent;
}

#padlock-ib[padshow="ib-trans-bg"][level="high"] {
  list-style-image: url("chrome://browser/content/padlock_mod_https.png");
  background-color: transparent;
}

#padlock-ib[padshow="ib-trans-bg"][level="low"] {
  list-style-image: url("chrome://browser/content/padlock_mod_low.png");
  background-color: transparent;
}

#padlock-ib[padshow="ib-trans-bg"][level="mixed"] {
  list-style-image: url("chrome://browser/content/padlock_mod_mixed.png");
  background-color: transparent;
}

#padlock-ib[padshow="ib-trans-bg"][level="broken"] {
  list-style-image: url("chrome://browser/content/padlock_mod_broken.png");
  background-color: transparent;
}

#padlock-ib-left {
  appearance: none;
  min-width: 0px;
  margin-right: 1px !important;
  background-repeat: no-repeat;
  background-position: center;
  z-index: 1000 !important;
  padding: 0px;
  margin: 0px;
  border: 0px; 
}

#padlock-ib-left[padshow="ib-left"][level="ev"] {
  list-style-image: url("chrome://browser/content/padlock_mod_ev.png");
  padding: 2px;
  background-color: transparent;
}

#padlock-ib-left[padshow="ib-left"][level="high"] {
  list-style-image: url("chrome://browser/content/padlock_mod_https.png");
  padding: 2px;
  background-color: transparent;
}

#padlock-ib-left[padshow="ib-left"][level="low"] {
  list-style-image: url("chrome://browser/content/padlock_mod_low.png");
  padding: 2px;
  background-color: transparent;
}

#padlock-ib-left[padshow="ib-left"][level="mixed"] {
  list-style-image: url("chrome://browser/content/padlock_mod_mixed.png");
  padding: 2px;
  background-color: transparent;
}

#padlock-ib-left[padshow="ib-left"][level="broken"] {
  list-style-image: url("chrome://browser/content/padlock_mod_broken.png");
  padding: 2px;
  background-color: transparent;
}

#padlock-ub-right {
  appearance: none;
  min-width: 0px;
  margin-right: 1px !important;
  background-repeat: no-repeat;
  background-position: center;
  z-index: 1000 !important;
  padding: 0px;
  margin: 0px;
  border: 0px; 
}

#padlock-ub-right[padshow="ub-right"][level="ev"] {
  list-style-image: url("chrome://browser/content/padlock_mod_ev.png");
  background-color: transparent;
}

#padlock-ub-right[padshow="ub-right"][level="high"] {
  list-style-image: url("chrome://browser/content/padlock_mod_https.png");
  background-color: transparent;
}

#padlock-ub-right[padshow="ub-right"][level="low"] {
  list-style-image: url("chrome://browser/content/padlock_mod_low.png");
  background-color: transparent;
}

#padlock-ub-right[padshow="ub-right"][level="mixed"] {
  list-style-image: url("chrome://browser/content/padlock_mod_mixed.png");
  background-color: transparent;
}

#padlock-ub-right[padshow="ub-right"][level="broken"] {
  list-style-image: url("chrome://browser/content/padlock_mod_broken.png");
  background-color: transparent;
}

#padlock-sb {
  appearance: none;
  background-repeat: no-repeat;
  background-position: center;
}

#padlock-sb[padshow="statbar"][level="ev"] {
  list-style-image: url("chrome://browser/content/padlock_mod_ev.png");
  background-color: transparent;
}

#padlock-sb[padshow="statbar"][level="high"] {
  list-style-image: url("chrome://browser/content/padlock_mod_https.png");
  background-color: transparent;
}

#padlock-sb[padshow="statbar"][level="low"] {
  list-style-image: url("chrome://browser/content/padlock_mod_low.png");
  background-color: transparent;
}

#padlock-sb[padshow="statbar"][level="mixed"] {
  list-style-image: url("chrome://browser/content/padlock_mod_mixed.png");
  background-color: transparent;
}

#padlock-sb[padshow="statbar"][level="broken"] {
  list-style-image: url("chrome://browser/content/padlock_mod_broken.png");
  background-color: transparent;
}

#padlock-tab {
  appearance: none;
  background-repeat: no-repeat;
  background-position: center;
}

#padlock-tab[padshow="tabs-bar"][level="ev"] {
  list-style-image: url("chrome://browser/content/padlock_mod_ev.png");
  background-color: transparent;
}

#padlock-tab[padshow="tabs-bar"][level="high"] {
  list-style-image: url("chrome://browser/content/padlock_mod_https.png");
  background-color: transparent;
}

#padlock-tab[padshow="tabs-bar"][level="low"] {
  list-style-image: url("chrome://browser/content/padlock_mod_low.png");
  background-color: transparent;
}

#padlock-tab[padshow="tabs-bar"][level="mixed"] {
  list-style-image: url("chrome://browser/content/padlock_mod_mixed.png");
  background-color: transparent;
}

#padlock-tab[padshow="tabs-bar"][level="broken"] {
  list-style-image: url("chrome://browser/content/padlock_mod_broken.png");
  background-color: transparent;
}

/* Classic style */
#padlock-ib[padshow="ib-trans-bg"][padstyle="classic"][level="ev"],
#padlock-ib-left[padshow="ib-left"][padstyle="classic"][level="ev"],
#padlock-ub-right[padshow="ub-right"][padstyle="classic"][level="ev"],
#padlock-sb[padshow="statbar"][padstyle="classic"][level="ev"],
#padlock-tab[padshow="tabs-bar"][padstyle="classic"][level="ev"] {
  list-style-image: url("chrome://browser/content/padlock_classic_ev.png");
}

#padlock-ib[padshow="ib-trans-bg"][padstyle="classic"][level="high"],
#padlock-ib-left[padshow="ib-left"][padstyle="classic"][level="high"],
#padlock-ub-right[padshow="ub-right"][padstyle="classic"][level="high"],
#padlock-sb[padshow="statbar"][padstyle="classic"][level="high"],
#padlock-tab[padshow="tabs-bar"][padstyle="classic"][level="high"] {
  list-style-image: url("chrome://browser/content/padlock_classic_https.png");
}

#padlock-ib[padshow="ib-trans-bg"][padstyle="classic"][level="low"],
#padlock-ib-left[padshow="ib-left"][padstyle="classic"][level="low"],
#padlock-ub-right[padshow="ub-right"][padstyle="classic"][level="low"],
#padlock-sb[padshow="statbar"][padstyle="classic"][level="low"],
#padlock-tab[padshow="tabs-bar"][padstyle="classic"][level="low"] {
  list-style-image: url("chrome://browser/content/padlock_classic_low.png");
}

#padlock-ib[padshow="ib-trans-bg"][padstyle="classic"][level="mixed"],
#padlock-ib-left[padshow="ib-left"][padstyle="classic"][level="mixed"],
#padlock-ub-right[padshow="ub-right"][padstyle="classic"][level="mixed"],
#padlock-sb[padshow="statbar"][padstyle="classic"][level="mixed"],
#padlock-tab[padshow="tabs-bar"][padstyle="classic"][level="mixed"] {
  list-style-image: url("chrome://browser/content/padlock_classic_mixed.png");
}

#padlock-ib[padshow="ib-trans-bg"][padstyle="classic"][level="broken"],
#padlock-ib-left[padshow="ib-left"][padstyle="classic"][level="broken"],
#padlock-ub-right[padshow="ub-right"][padstyle="classic"][level="broken"],
#padlock-sb[padshow="statbar"][padstyle="classic"][level="broken"],
#padlock-tab[padshow="tabs-bar"][padstyle="classic"][level="broken"] {
  list-style-image: url("chrome://browser/content/padlock_classic_broken.png");
}

/* Remove a few px of dead space for disabled locations */
#padlock-ib:not([padshow="ib-trans-bg"]),
#padlock-ib-left:not([padshow="ib-left"]),
#padlock-ub-right:not([padshow="ub-right"]),
#padlock-sb:not([padshow="statbar"]),
#padlock-tab:not([padshow="tabs-bar"]) {
    visibility: collapse;
}